clear all;
clc;

disp(' ');
filename = 'WithZeroElectrodes.mat';
load(filename);
disp(['Analyzing Data for: ' filename]);
disp('=========================');

idx = 1;
test = 1;
x = -25:1:25;
y = -25:1:25;

J_mag = data(:,3);
J_x = data(:,4);
J_y = data(:,5);
z_n = zeros(length(x), length(y));

for i_x = 1:length(x)
    for i_y = 1:length(y)

        cmat(i_y,i_x) = (x(i_x) - i*y(i_y)); 
        
        if (J_mag(idx) < 22)
            J_mag_mat(i_y,i_x) = J_mag(idx);
        else
            J_mag_mat(i_y,i_x) = 8;
        end
        
        radius = sqrt(x(i_x)^2+y(i_y)^2);
        if (radius <= 25.2)
            rad(i_y,i_x) = radius;
            ang = 180*atan(y(i_y)/x(i_x))/pi;
            sign_ang = sign(x(i_x));
            angle(i_y,i_x) = ang * sign_ang;

            rot1_ang = angle(i_y,i_x) + 120;
            rot2_ang = angle(i_y,i_x) + 240;

            x_1 = round (radius * cos(rot1_ang*pi/180));
            y_1 = round (radius * sin(rot1_ang*pi/180));
            x_2 = round (radius * cos(rot2_ang*pi/180));
            y_2 = round (radius * sin(rot2_ang*pi/180));
            
            cmat1(i_y,i_x) = x_1 + i*y_1;
            cmat2(i_y,i_x) = x_2 + i*y_2;            
        else
            rad(i_y,i_x) = 0;
            angle(i_y,i_x) = 0;
        end
        
        idx = idx+1;
    end
end

for i_x = 1:length(x)
    for i_y = 1:length(y)

        J1 = J_mag_mat(i_y,i_x);
        xv = x(i_x); 
        yv = y(i_y);
        radius = sqrt(xv^2 + yv^2);
        if ((radius <= 25.2) && (radius > 0))

            i_x_1 = real(cmat1(i_y,i_x)) + 26;
            i_y_1 = 26 - imag(cmat1(i_y,i_x));
            J2 = J_mag_mat(i_y_1, i_x_1);

            i_x_2 = real(cmat2(i_y,i_x)) + 26;
            i_y_2 = 26 - imag(cmat2(i_y,i_x));
            J3 = J_mag_mat(i_y_2, i_x_2);
            
%             fmtstr = 'For x,y = %+03d,%+03d, iX2,iY2 = %+03d,%+03d';
%             dispstr = sprintf(fmtstr,xv, yv, i_x_2, i_y_2);
%             disp(dispstr);
        else
            J2 = J_mag_mat(26, 26);
            J3 = J_mag_mat(26, 26);           
        end
        J_avg(i_y, i_x) = (J1 + J2 + J3)/3;
    end
    
end

disp('Results for average field magnitude...')
subplot(2,2,1)
surf(x,y,J_avg);
title('Surf plot of Average(Magnitude(Field))')
subplot(2,2,2);
scalefactor = 70/max(max(J_avg));
image(scalefactor*J_avg);
colorbar;

axis('square')
title('Colormap of Average(Magnitude(Field))')

nonzero_elements = nonzeros(J_avg);
num_nonzeros = nnz(J_mag_mat);
mean_nz = mean(nonzero_elements);

normalized_data = J_mag_mat/mean_nz;
normalized_nz_data = nonzero_elements/mean_nz;
decibel_data = 20*log10(normalized_nz_data);

bins = 0.1:0.1:2.2;

histdata = hist(normalized_nz_data, bins);
histdata_percent = 100*histdata / sum(histdata);
db_bins = 20*log10(bins);

poscumhistdata = 100 * cumsum (histdata)/num_nonzeros;
negcumhistdata = 100 * (num_nonzeros - cumsum (histdata))/num_nonzeros;

dispstr = ['Bin  Bin_db  %    Cum%'];
disp(dispstr)
disp('=========================')

hstpcnt = histdata_percent;

for idx = 1:length(bins)
    dispstr = sprintf('%04.2f %+06.2f %04.1f %05.1f', bins(idx),db_bins(idx),hstpcnt(idx),poscumhistdata(idx));
    disp(dispstr);
end

% 
outdata = zeros(length(bins),3);
outdata(:,1) = bins';
outdata(:,2) = db_bins';
outdata(:,3) = histdata';

idx_array_6dB = find(abs (db_bins) > 6);
idx_array_3dB = find(abs (db_bins) < 3.2);
total_6dB_area = sum(hstpcnt(idx_array_6dB));
total_3dB_area = sum(hstpcnt(idx_array_3dB));

disp(' ');
dispstr = sprintf('The total area greater than +/- 6dB = %4.1f %%', total_6dB_area);
disp(dispstr);
dispstr = sprintf('The total area within than +/- 3.1dB = %4.1f %%', total_3dB_area);
disp(dispstr);


disp(' ');
disp('Results for one rotation field magnitude...')
subplot(2,2,3)
surf(x,y,J_mag_mat);

title('Surf plot of One Field Rotation');
subplot(2,2,4)
scalefactor = 100/max(max(J_mag_mat));
image(uint8(scalefactor*J_mag_mat));
colorbar;

axis('square')
title('Colormap of One Field Rotation');

nonzero_elements = nonzeros(J_mag_mat);
num_nonzeros = nnz(J_mag_mat);
mean_nz = mean(nonzero_elements);

normalized_data = z_n/mean_nz;
normalized_nz_data = nonzero_elements/mean_nz;
decibel_data = 20*log10(normalized_nz_data);

bins = 0.1:0.1:2.2;

histdata = hist(normalized_nz_data, bins);
histdata_percent = 100*histdata / sum(histdata);
db_bins = 20*log10(bins);

poscumhistdata = 100 * cumsum (histdata)/num_nonzeros;
negcumhistdata = 100 * (num_nonzeros - cumsum (histdata))/num_nonzeros;

dispstr = ['Bin  Bin_db  %    Cum%'];
disp(dispstr)
disp('=========================')


hstpcnt = histdata_percent;

for idx = 1:length(bins)
    dispstr = sprintf('%04.2f %+06.2f %04.1f %05.1f', bins(idx),db_bins(idx),hstpcnt(idx),poscumhistdata(idx));
    disp(dispstr);
end


% subplot(2,2,1:2)
% surf(x,y,normalized_data);
% 
% subplot(2,2,3)
% bar(bins, histdata);
% subplot(2,2,4)
% bar(db_bins, histdata);
% 
outdata = zeros(length(bins),3);
outdata(:,1) = bins';
outdata(:,2) = db_bins';
outdata(:,3) = histdata';

idx_array_6dB = find(abs (db_bins) > 6);
idx_array_3dB = find(abs (db_bins) < 3.2);
total_6dB_area = sum(hstpcnt(idx_array_6dB));
total_3dB_area = sum(hstpcnt(idx_array_3dB));

disp(' ');
dispstr = sprintf('The total area greater than +/- 6dB = %4.1f %%', total_6dB_area);
disp(dispstr);
dispstr = sprintf('The total area within than +/- 3.1dB = %4.1f %%', total_3dB_area);
disp(dispstr);
